function CDBM3D_hat = CD_BM3D_Separate_Thresholding_parameters(sigma, Z, lambda3D, NStep, nmFact, Ns, ConfFact, upConfFact, lambda2D, SVD3D)
%%
%% (c) Vladimir Katkovnik, Tampere, TUT, March 2016
%%
%% sigma value for the noise (.1 .3 .5 .7 .9)
%%
%% Z - noisy signal
%%
%% varphi - true phase
%%
%% lambda3D:  threshold parameter (1.5 .. 3)
%%
%% NStep: sliding step (usually equal to 3) to process every next reference block
%%
%% nmFact: multiplication factor (usually equal to 1) for maximum number of similar blocks (maximum size of the 3rd dimension of a 3D array)
%%
%% Ns: length of the side of the search neighborhood for full-search block-matching (BM), must be odd (ususlly equal to 39)
%%
%% ConfFact: parameter (usually equal to 2) for the two sides symmetric confidence interval for grouping
%%
%% upConfFact: parameter (usually equal to 10) for the upper bound in the two sides non-symmetric confidence interval for grouping
%%
%% lambda2D: threshold parameter (usually equal to 0) for the coarse initial denoising used in the d-distance measure
%%
%% SVD3D: 1 stays for high-order 3D SVD, otherwise 2D SVD

sigma = 255*sigma;

[M,N]=size(Z);

param.nm1 = 8;  %% N1 x N1 is the block size used for the hard-thresholding (HT) filtering
param.Nstep =NStep; %% sliding step to process every next reference block
param.nm2 =floor(nmFact*param.nm1*param.nm1/2); %% maximum number of similar blocks (maximum size of the 3rd dimension of a 3D array)
param.Ns = Ns;  %% length of the side of the search neighborhood for full-search block-matching (BM), must be odd

param.lambda3D=lambda3D;         %% parameter for the thresholding
param.lambda_conf_int=ConfFact;         %% parameter for the two sides symmetric confidence interval for grouping
param.lambda_conf_int_factor=upConfFact; %% parameter for the upper bound in the two sides non-symmetric confidence interval for grouping
param.doBlockMatching=1;         %% false (0) means that the new grouping is produced, true (1) means that the previous grouping is used 
param.bm2D3Dhosvd_index3D=SVD3D;     %% 1 stays for high-order 3D SVD, otherwise 2D SVD
param.sigma = sigma;             %% STD of the additive Gaussian noise
param.lambda2D =  lambda2D;     %% threshold parameter for the coarse initial denoising used in the d-distance measure

%% two-sided confidence interval for grouping of similar patches
%lower bound
param.lambda_conf(1)=max(0,(param.nm1^2-param.lambda_conf_int*sqrt(2*param.nm1^2))*param.sigma^2*2/255^2);
%upper bound
param.lambda_conf(2)= (param.nm1^2+param.lambda_conf_int*sqrt(2*param.nm1^2))*param.sigma^2*2/255^2*param.lambda_conf_int_factor;

[CDBM3D_hat,nnzTransfElements]  = CD_BM3D_Separate_Thresholding(Z, param);

end
